# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreMessageDataForMessageareaSearchMessagesResponseContactsInner(BaseModel):
    """
    CoreMessageDataForMessageareaSearchMessagesResponseContactsInner
    """ # noqa: E501
    conversationid: Optional[StrictInt] = Field(default=None, description="The id of the conversation")
    fullname: Optional[StrictStr] = Field(description="The user's name")
    isblocked: Optional[StrictBool] = Field(description="If the user has been blocked")
    ismessaging: Optional[StrictBool] = Field(description="If we are messaging the user")
    isonline: Optional[StrictBool] = Field(description="The user's online status")
    isread: Optional[StrictBool] = Field(description="If the user has read the message")
    lastmessage: Optional[StrictStr] = Field(description="The user's last message")
    lastmessagedate: Optional[StrictInt] = Field(default=None, description="Timestamp for last message")
    messageid: Optional[StrictInt] = Field(default=None, description="The unique search message id")
    profileimageurl: Optional[StrictStr] = Field(description="User picture URL")
    profileimageurlsmall: Optional[StrictStr] = Field(description="Small user picture URL")
    sentfromcurrentuser: Optional[StrictBool] = Field(description="Was the last message sent from the current user?")
    showonlinestatus: Optional[StrictBool] = Field(description="Show the user's online status?")
    unreadcount: Optional[StrictInt] = Field(default=None, description="The number of unread messages in this conversation")
    userid: Optional[StrictInt] = Field(description="The user's id")
    __properties: ClassVar[List[str]] = ["conversationid", "fullname", "isblocked", "ismessaging", "isonline", "isread", "lastmessage", "lastmessagedate", "messageid", "profileimageurl", "profileimageurlsmall", "sentfromcurrentuser", "showonlinestatus", "unreadcount", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreMessageDataForMessageareaSearchMessagesResponseContactsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if conversationid (nullable) is None
        # and model_fields_set contains the field
        if self.conversationid is None and "conversationid" in self.model_fields_set:
            _dict['conversationid'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if isblocked (nullable) is None
        # and model_fields_set contains the field
        if self.isblocked is None and "isblocked" in self.model_fields_set:
            _dict['isblocked'] = None

        # set to None if ismessaging (nullable) is None
        # and model_fields_set contains the field
        if self.ismessaging is None and "ismessaging" in self.model_fields_set:
            _dict['ismessaging'] = None

        # set to None if isonline (nullable) is None
        # and model_fields_set contains the field
        if self.isonline is None and "isonline" in self.model_fields_set:
            _dict['isonline'] = None

        # set to None if isread (nullable) is None
        # and model_fields_set contains the field
        if self.isread is None and "isread" in self.model_fields_set:
            _dict['isread'] = None

        # set to None if lastmessage (nullable) is None
        # and model_fields_set contains the field
        if self.lastmessage is None and "lastmessage" in self.model_fields_set:
            _dict['lastmessage'] = None

        # set to None if lastmessagedate (nullable) is None
        # and model_fields_set contains the field
        if self.lastmessagedate is None and "lastmessagedate" in self.model_fields_set:
            _dict['lastmessagedate'] = None

        # set to None if messageid (nullable) is None
        # and model_fields_set contains the field
        if self.messageid is None and "messageid" in self.model_fields_set:
            _dict['messageid'] = None

        # set to None if profileimageurl (nullable) is None
        # and model_fields_set contains the field
        if self.profileimageurl is None and "profileimageurl" in self.model_fields_set:
            _dict['profileimageurl'] = None

        # set to None if profileimageurlsmall (nullable) is None
        # and model_fields_set contains the field
        if self.profileimageurlsmall is None and "profileimageurlsmall" in self.model_fields_set:
            _dict['profileimageurlsmall'] = None

        # set to None if sentfromcurrentuser (nullable) is None
        # and model_fields_set contains the field
        if self.sentfromcurrentuser is None and "sentfromcurrentuser" in self.model_fields_set:
            _dict['sentfromcurrentuser'] = None

        # set to None if showonlinestatus (nullable) is None
        # and model_fields_set contains the field
        if self.showonlinestatus is None and "showonlinestatus" in self.model_fields_set:
            _dict['showonlinestatus'] = None

        # set to None if unreadcount (nullable) is None
        # and model_fields_set contains the field
        if self.unreadcount is None and "unreadcount" in self.model_fields_set:
            _dict['unreadcount'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreMessageDataForMessageareaSearchMessagesResponseContactsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreMessageDataForMessageareaSearchMessagesResponseContactsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "conversationid": obj.get("conversationid"),
            "fullname": obj.get("fullname"),
            "isblocked": obj.get("isblocked"),
            "ismessaging": obj.get("ismessaging"),
            "isonline": obj.get("isonline"),
            "isread": obj.get("isread"),
            "lastmessage": obj.get("lastmessage"),
            "lastmessagedate": obj.get("lastmessagedate"),
            "messageid": obj.get("messageid"),
            "profileimageurl": obj.get("profileimageurl"),
            "profileimageurlsmall": obj.get("profileimageurlsmall"),
            "sentfromcurrentuser": obj.get("sentfromcurrentuser"),
            "showonlinestatus": obj.get("showonlinestatus"),
            "unreadcount": obj.get("unreadcount"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt_gradeitemmarks_inner import ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModQuizGetUserAttemptsResponseAttemptsInner(BaseModel):
    """
    ModQuizGetUserAttemptsResponseAttemptsInner
    """ # noqa: E501
    attempt: Optional[StrictInt] = Field(default=None, description="Sequentially numbers this students attempts at this quiz.")
    currentpage: Optional[StrictInt] = Field(default=None, description="Attempt current page.")
    gradednotificationsenttime: Optional[StrictInt] = Field(default=None, description="Time when the student was notified that manual grading of their attempt was complete.")
    gradeitemmarks: Optional[List[ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner]] = Field(default=None, description="If the quiz has additional grades set up, the mark for each grade for this attempt.")
    id: Optional[StrictInt] = Field(default=None, description="Attempt id.")
    layout: Optional[StrictStr] = Field(default=None, description="Attempt layout.")
    preview: Optional[StrictInt] = Field(default=None, description="Whether is a preview attempt or not.")
    quiz: Optional[StrictInt] = Field(default=None, description="Foreign key reference to the quiz that was attempted.")
    state: Optional[StrictStr] = Field(default=None, description="The current state of the attempts. 'inprogress',                                                 'overdue', 'finished' or 'abandoned'. For backwards compatibility, attempts in 'submitted' state will return 'finished' and attempts in 'notstarted' state will return 'inprogress'. To get attempts with all real states, call get_user_quiz_attempts() instead.")
    sumgrades: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Total marks for this attempt.")
    timecheckstate: Optional[StrictInt] = Field(default=None, description="Next time quiz cron should check attempt for                                                         state changes.  NULL means never check.")
    timefinish: Optional[StrictInt] = Field(default=None, description="Time when the attempt was submitted.                                                     0 if the attempt has not been submitted yet.")
    timemodified: Optional[StrictInt] = Field(default=None, description="Last modified time.")
    timemodifiedoffline: Optional[StrictInt] = Field(default=None, description="Last modified time via webservices.")
    timestart: Optional[StrictInt] = Field(default=None, description="Time when the attempt was started.")
    uniqueid: Optional[StrictInt] = Field(default=None, description="Foreign key reference to the question_usage that holds the                                                     details of the the question_attempts that make up this quiz                                                     attempt.")
    userid: Optional[StrictInt] = Field(default=None, description="Foreign key reference to the user whose attempt this is.")
    __properties: ClassVar[List[str]] = ["attempt", "currentpage", "gradednotificationsenttime", "gradeitemmarks", "id", "layout", "preview", "quiz", "state", "sumgrades", "timecheckstate", "timefinish", "timemodified", "timemodifiedoffline", "timestart", "uniqueid", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModQuizGetUserAttemptsResponseAttemptsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in gradeitemmarks (list)
        _items = []
        if self.gradeitemmarks:
            for _item_gradeitemmarks in self.gradeitemmarks:
                if _item_gradeitemmarks:
                    _items.append(_item_gradeitemmarks.to_dict())
            _dict['gradeitemmarks'] = _items
        # set to None if attempt (nullable) is None
        # and model_fields_set contains the field
        if self.attempt is None and "attempt" in self.model_fields_set:
            _dict['attempt'] = None

        # set to None if currentpage (nullable) is None
        # and model_fields_set contains the field
        if self.currentpage is None and "currentpage" in self.model_fields_set:
            _dict['currentpage'] = None

        # set to None if gradednotificationsenttime (nullable) is None
        # and model_fields_set contains the field
        if self.gradednotificationsenttime is None and "gradednotificationsenttime" in self.model_fields_set:
            _dict['gradednotificationsenttime'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if layout (nullable) is None
        # and model_fields_set contains the field
        if self.layout is None and "layout" in self.model_fields_set:
            _dict['layout'] = None

        # set to None if preview (nullable) is None
        # and model_fields_set contains the field
        if self.preview is None and "preview" in self.model_fields_set:
            _dict['preview'] = None

        # set to None if quiz (nullable) is None
        # and model_fields_set contains the field
        if self.quiz is None and "quiz" in self.model_fields_set:
            _dict['quiz'] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict['state'] = None

        # set to None if sumgrades (nullable) is None
        # and model_fields_set contains the field
        if self.sumgrades is None and "sumgrades" in self.model_fields_set:
            _dict['sumgrades'] = None

        # set to None if timecheckstate (nullable) is None
        # and model_fields_set contains the field
        if self.timecheckstate is None and "timecheckstate" in self.model_fields_set:
            _dict['timecheckstate'] = None

        # set to None if timefinish (nullable) is None
        # and model_fields_set contains the field
        if self.timefinish is None and "timefinish" in self.model_fields_set:
            _dict['timefinish'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if timemodifiedoffline (nullable) is None
        # and model_fields_set contains the field
        if self.timemodifiedoffline is None and "timemodifiedoffline" in self.model_fields_set:
            _dict['timemodifiedoffline'] = None

        # set to None if timestart (nullable) is None
        # and model_fields_set contains the field
        if self.timestart is None and "timestart" in self.model_fields_set:
            _dict['timestart'] = None

        # set to None if uniqueid (nullable) is None
        # and model_fields_set contains the field
        if self.uniqueid is None and "uniqueid" in self.model_fields_set:
            _dict['uniqueid'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModQuizGetUserAttemptsResponseAttemptsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModQuizGetUserAttemptsResponseAttemptsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "attempt": obj.get("attempt"),
            "currentpage": obj.get("currentpage"),
            "gradednotificationsenttime": obj.get("gradednotificationsenttime"),
            "gradeitemmarks": [ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner.from_dict(_item) for _item in obj["gradeitemmarks"]] if obj.get("gradeitemmarks") is not None else None,
            "id": obj.get("id"),
            "layout": obj.get("layout"),
            "preview": obj.get("preview"),
            "quiz": obj.get("quiz"),
            "state": obj.get("state"),
            "sumgrades": obj.get("sumgrades"),
            "timecheckstate": obj.get("timecheckstate"),
            "timefinish": obj.get("timefinish"),
            "timemodified": obj.get("timemodified"),
            "timemodifiedoffline": obj.get("timemodifiedoffline"),
            "timestart": obj.get("timestart"),
            "uniqueid": obj.get("uniqueid"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.auth_email_signup_user_parameters_customprofilefields_inner import AuthEmailSignupUserParametersCustomprofilefieldsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class AuthEmailSignupUserParameters(BaseModel):
    """
    AuthEmailSignupUserParameters
    """ # noqa: E501
    city: Optional[StrictStr] = Field(default='', description="Home city of the user")
    country: Optional[StrictStr] = Field(default='', description="Home country code")
    customprofilefields: Optional[List[AuthEmailSignupUserParametersCustomprofilefieldsInner]] = Field(default=None, description="User custom fields (also known as user profile fields)")
    email: Optional[StrictStr] = Field(description="A valid and unique email address")
    firstname: Optional[StrictStr] = Field(description="The first name(s) of the user")
    lastname: Optional[StrictStr] = Field(description="The family name of the user")
    password: Optional[StrictStr] = Field(description="Plain text password")
    recaptchachallengehash: Optional[StrictStr] = Field(default='', description="Recaptcha challenge hash")
    recaptcharesponse: Optional[StrictStr] = Field(default='', description="Recaptcha response")
    redirect: Optional[StrictStr] = Field(default='', description="Redirect the user to this site url after confirmation.")
    username: Optional[StrictStr] = Field(description="Username")
    __properties: ClassVar[List[str]] = ["city", "country", "customprofilefields", "email", "firstname", "lastname", "password", "recaptchachallengehash", "recaptcharesponse", "redirect", "username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuthEmailSignupUserParameters from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in customprofilefields (list)
        _items = []
        if self.customprofilefields:
            for _item_customprofilefields in self.customprofilefields:
                if _item_customprofilefields:
                    _items.append(_item_customprofilefields.to_dict())
            _dict['customprofilefields'] = _items
        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if firstname (nullable) is None
        # and model_fields_set contains the field
        if self.firstname is None and "firstname" in self.model_fields_set:
            _dict['firstname'] = None

        # set to None if lastname (nullable) is None
        # and model_fields_set contains the field
        if self.lastname is None and "lastname" in self.model_fields_set:
            _dict['lastname'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if recaptchachallengehash (nullable) is None
        # and model_fields_set contains the field
        if self.recaptchachallengehash is None and "recaptchachallengehash" in self.model_fields_set:
            _dict['recaptchachallengehash'] = None

        # set to None if recaptcharesponse (nullable) is None
        # and model_fields_set contains the field
        if self.recaptcharesponse is None and "recaptcharesponse" in self.model_fields_set:
            _dict['recaptcharesponse'] = None

        # set to None if redirect (nullable) is None
        # and model_fields_set contains the field
        if self.redirect is None and "redirect" in self.model_fields_set:
            _dict['redirect'] = None

        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuthEmailSignupUserParameters from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "AuthEmailSignupUserParameters" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "city": obj.get("city") if obj.get("city") is not None else '',
            "country": obj.get("country") if obj.get("country") is not None else '',
            "customprofilefields": [AuthEmailSignupUserParametersCustomprofilefieldsInner.from_dict(_item) for _item in obj["customprofilefields"]] if obj.get("customprofilefields") is not None else None,
            "email": obj.get("email"),
            "firstname": obj.get("firstname"),
            "lastname": obj.get("lastname"),
            "password": obj.get("password"),
            "recaptchachallengehash": obj.get("recaptchachallengehash") if obj.get("recaptchachallengehash") is not None else '',
            "recaptcharesponse": obj.get("recaptcharesponse") if obj.get("recaptcharesponse") is not None else '',
            "redirect": obj.get("redirect") if obj.get("redirect") is not None else '',
            "username": obj.get("username")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_comments_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_criterion_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class GradingformGuideGraderGradingpanelFetchResponseGrade(BaseModel):
    """
    GradingformGuideGraderGradingpanelFetchResponseGrade
    """ # noqa: E501
    comments: List[GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner] = Field(description="Frequently used comments")
    criterion: List[GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner] = Field(description="The criterion by which this item will be graded")
    gradedby: Optional[StrictStr] = Field(description="The assumed grader of this grading instance")
    hascomments: Optional[StrictBool] = Field(description="Whether there are any frequently-used comments")
    instanceid: Optional[StrictInt] = Field(description="The id of the current grading instance")
    maxgrade: Optional[StrictStr] = Field(description="Max possible grade")
    timecreated: Optional[StrictInt] = Field(description="The time that the grade was created")
    timemodified: Optional[StrictInt] = Field(description="The time that the grade was last updated")
    usergrade: Optional[StrictStr] = Field(description="Current user grade")
    __properties: ClassVar[List[str]] = ["comments", "criterion", "gradedby", "hascomments", "instanceid", "maxgrade", "timecreated", "timemodified", "usergrade"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GradingformGuideGraderGradingpanelFetchResponseGrade from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in comments (list)
        _items = []
        if self.comments:
            for _item_comments in self.comments:
                if _item_comments:
                    _items.append(_item_comments.to_dict())
            _dict['comments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in criterion (list)
        _items = []
        if self.criterion:
            for _item_criterion in self.criterion:
                if _item_criterion:
                    _items.append(_item_criterion.to_dict())
            _dict['criterion'] = _items
        # set to None if gradedby (nullable) is None
        # and model_fields_set contains the field
        if self.gradedby is None and "gradedby" in self.model_fields_set:
            _dict['gradedby'] = None

        # set to None if hascomments (nullable) is None
        # and model_fields_set contains the field
        if self.hascomments is None and "hascomments" in self.model_fields_set:
            _dict['hascomments'] = None

        # set to None if instanceid (nullable) is None
        # and model_fields_set contains the field
        if self.instanceid is None and "instanceid" in self.model_fields_set:
            _dict['instanceid'] = None

        # set to None if maxgrade (nullable) is None
        # and model_fields_set contains the field
        if self.maxgrade is None and "maxgrade" in self.model_fields_set:
            _dict['maxgrade'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if usergrade (nullable) is None
        # and model_fields_set contains the field
        if self.usergrade is None and "usergrade" in self.model_fields_set:
            _dict['usergrade'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GradingformGuideGraderGradingpanelFetchResponseGrade from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "GradingformGuideGraderGradingpanelFetchResponseGrade" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "comments": [GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner.from_dict(_item) for _item in obj["comments"]] if obj.get("comments") is not None else None,
            "criterion": [GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner.from_dict(_item) for _item in obj["criterion"]] if obj.get("criterion") is not None else None,
            "gradedby": obj.get("gradedby"),
            "hascomments": obj.get("hascomments"),
            "instanceid": obj.get("instanceid"),
            "maxgrade": obj.get("maxgrade"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "usergrade": obj.get("usergrade")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.auth_email_get_signup_settings_response_profilefields_inner import AuthEmailGetSignupSettingsResponseProfilefieldsInner
from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class AuthEmailGetSignupSettingsResponse(BaseModel):
    """
    AuthEmailGetSignupSettingsResponse
    """ # noqa: E501
    country: Optional[StrictStr] = Field(default=None, description="Default country")
    defaultcity: Optional[StrictStr] = Field(default=None, description="Default city")
    extendedusernamechars: Optional[StrictBool] = Field(default=None, description="Extended characters in usernames or not")
    namefields: List[Optional[StrictStr]]
    passwordpolicy: Optional[StrictStr] = Field(default=None, description="Password policy")
    profilefields: Optional[List[AuthEmailGetSignupSettingsResponseProfilefieldsInner]] = Field(default=None, description="Required profile fields")
    recaptchachallengehash: Optional[StrictStr] = Field(default=None, description="Recaptcha challenge hash")
    recaptchachallengeimage: Optional[StrictStr] = Field(default=None, description="Recaptcha challenge noscript image")
    recaptchachallengejs: Optional[StrictStr] = Field(default=None, description="Recaptcha challenge js url")
    recaptchapublickey: Optional[StrictStr] = Field(default=None, description="Recaptcha public key")
    sitepolicy: Optional[StrictStr] = Field(default=None, description="Site policy")
    sitepolicyhandler: Optional[StrictStr] = Field(default=None, description="Site policy handler")
    warnings: Optional[List[AuthEmailGetSignupSettingsResponseWarningsInner]] = Field(default=None, description="list of warnings")
    __properties: ClassVar[List[str]] = ["country", "defaultcity", "extendedusernamechars", "namefields", "passwordpolicy", "profilefields", "recaptchachallengehash", "recaptchachallengeimage", "recaptchachallengejs", "recaptchapublickey", "sitepolicy", "sitepolicyhandler", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuthEmailGetSignupSettingsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in profilefields (list)
        _items = []
        if self.profilefields:
            for _item_profilefields in self.profilefields:
                if _item_profilefields:
                    _items.append(_item_profilefields.to_dict())
            _dict['profilefields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item_warnings in self.warnings:
                if _item_warnings:
                    _items.append(_item_warnings.to_dict())
            _dict['warnings'] = _items
        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if defaultcity (nullable) is None
        # and model_fields_set contains the field
        if self.defaultcity is None and "defaultcity" in self.model_fields_set:
            _dict['defaultcity'] = None

        # set to None if extendedusernamechars (nullable) is None
        # and model_fields_set contains the field
        if self.extendedusernamechars is None and "extendedusernamechars" in self.model_fields_set:
            _dict['extendedusernamechars'] = None

        # set to None if passwordpolicy (nullable) is None
        # and model_fields_set contains the field
        if self.passwordpolicy is None and "passwordpolicy" in self.model_fields_set:
            _dict['passwordpolicy'] = None

        # set to None if recaptchachallengehash (nullable) is None
        # and model_fields_set contains the field
        if self.recaptchachallengehash is None and "recaptchachallengehash" in self.model_fields_set:
            _dict['recaptchachallengehash'] = None

        # set to None if recaptchachallengeimage (nullable) is None
        # and model_fields_set contains the field
        if self.recaptchachallengeimage is None and "recaptchachallengeimage" in self.model_fields_set:
            _dict['recaptchachallengeimage'] = None

        # set to None if recaptchachallengejs (nullable) is None
        # and model_fields_set contains the field
        if self.recaptchachallengejs is None and "recaptchachallengejs" in self.model_fields_set:
            _dict['recaptchachallengejs'] = None

        # set to None if recaptchapublickey (nullable) is None
        # and model_fields_set contains the field
        if self.recaptchapublickey is None and "recaptchapublickey" in self.model_fields_set:
            _dict['recaptchapublickey'] = None

        # set to None if sitepolicy (nullable) is None
        # and model_fields_set contains the field
        if self.sitepolicy is None and "sitepolicy" in self.model_fields_set:
            _dict['sitepolicy'] = None

        # set to None if sitepolicyhandler (nullable) is None
        # and model_fields_set contains the field
        if self.sitepolicyhandler is None and "sitepolicyhandler" in self.model_fields_set:
            _dict['sitepolicyhandler'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuthEmailGetSignupSettingsResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "AuthEmailGetSignupSettingsResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "country": obj.get("country"),
            "defaultcity": obj.get("defaultcity"),
            "extendedusernamechars": obj.get("extendedusernamechars"),
            "namefields": obj.get("namefields"),
            "passwordpolicy": obj.get("passwordpolicy"),
            "profilefields": [AuthEmailGetSignupSettingsResponseProfilefieldsInner.from_dict(_item) for _item in obj["profilefields"]] if obj.get("profilefields") is not None else None,
            "recaptchachallengehash": obj.get("recaptchachallengehash"),
            "recaptchachallengeimage": obj.get("recaptchachallengeimage"),
            "recaptchachallengejs": obj.get("recaptchachallengejs"),
            "recaptchapublickey": obj.get("recaptchapublickey"),
            "sitepolicy": obj.get("sitepolicy"),
            "sitepolicyhandler": obj.get("sitepolicyhandler"),
            "warnings": [AuthEmailGetSignupSettingsResponseWarningsInner.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModWikiGetPageContentsResponsePage(BaseModel):
    """
    Page
    """ # noqa: E501
    cachedcontent: Optional[StrictStr] = Field(description="Page contents.")
    caneditpage: Optional[StrictBool] = Field(description="True if user can edit the page.")
    contentformat: Optional[StrictInt] = Field(default=None, description="cachedcontent format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    groupid: Optional[StrictInt] = Field(description="Page's group ID.")
    id: Optional[StrictInt] = Field(description="Page ID.")
    subwikiid: Optional[StrictInt] = Field(description="Page's subwiki ID.")
    tags: Optional[List[CoreBlogGetEntriesResponseEntriesInnerTagsInner]] = Field(default=None, description="Tags")
    title: Optional[StrictStr] = Field(description="Page title.")
    userid: Optional[StrictInt] = Field(description="Page's user ID.")
    version: Optional[StrictInt] = Field(default=None, description="Latest version of the page.")
    wikiid: Optional[StrictInt] = Field(description="Page's wiki ID.")
    __properties: ClassVar[List[str]] = ["cachedcontent", "caneditpage", "contentformat", "groupid", "id", "subwikiid", "tags", "title", "userid", "version", "wikiid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModWikiGetPageContentsResponsePage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if cachedcontent (nullable) is None
        # and model_fields_set contains the field
        if self.cachedcontent is None and "cachedcontent" in self.model_fields_set:
            _dict['cachedcontent'] = None

        # set to None if caneditpage (nullable) is None
        # and model_fields_set contains the field
        if self.caneditpage is None and "caneditpage" in self.model_fields_set:
            _dict['caneditpage'] = None

        # set to None if contentformat (nullable) is None
        # and model_fields_set contains the field
        if self.contentformat is None and "contentformat" in self.model_fields_set:
            _dict['contentformat'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if subwikiid (nullable) is None
        # and model_fields_set contains the field
        if self.subwikiid is None and "subwikiid" in self.model_fields_set:
            _dict['subwikiid'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if wikiid (nullable) is None
        # and model_fields_set contains the field
        if self.wikiid is None and "wikiid" in self.model_fields_set:
            _dict['wikiid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModWikiGetPageContentsResponsePage from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModWikiGetPageContentsResponsePage" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "cachedcontent": obj.get("cachedcontent"),
            "caneditpage": obj.get("caneditpage"),
            "contentformat": obj.get("contentformat"),
            "groupid": obj.get("groupid"),
            "id": obj.get("id"),
            "subwikiid": obj.get("subwikiid"),
            "tags": [CoreBlogGetEntriesResponseEntriesInnerTagsInner.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "title": obj.get("title"),
            "userid": obj.get("userid"),
            "version": obj.get("version"),
            "wikiid": obj.get("wikiid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreSearchGetResultsResponseResultsInner(BaseModel):
    """
    CoreSearchGetResultsResponseResultsInner
    """ # noqa: E501
    areaname: StrictStr = Field(description="search area name")
    componentname: StrictStr = Field(description="component name")
    content: Optional[StrictStr] = Field(default='', description="result contents")
    contextid: StrictInt = Field(description="result context id")
    contexturl: StrictStr = Field(description="result context url")
    coursefullname: StrictStr = Field(description="result course fullname")
    courseurl: StrictStr = Field(description="result course url")
    description1: Optional[StrictStr] = Field(default='', description="extra result contents, depends on the search area")
    description2: Optional[StrictStr] = Field(default='', description="extra result contents, depends on the search area")
    docurl: StrictStr = Field(description="result url")
    filename: Optional[StrictStr] = Field(default='', description="result file name if present")
    filenames: Optional[StrictStr] = Field(default='', description="result file names if present")
    iconurl: Optional[StrictStr] = Field(default='', description="icon url")
    itemid: StrictInt = Field(description="unique id in the search area scope")
    multiplefiles: Optional[StrictInt] = Field(default=0, description="whether multiple files are returned or not")
    textformat: StrictInt = Field(description="text fields format, it is the same for all of them")
    timemodified: StrictInt = Field(description="result modified time")
    title: StrictStr = Field(description="result title")
    userfullname: Optional[StrictStr] = Field(default='', description="user fullname")
    userid: Optional[StrictInt] = Field(default=0, description="user id")
    userurl: Optional[StrictStr] = Field(default='', description="user url")
    __properties: ClassVar[List[str]] = ["areaname", "componentname", "content", "contextid", "contexturl", "coursefullname", "courseurl", "description1", "description2", "docurl", "filename", "filenames", "iconurl", "itemid", "multiplefiles", "textformat", "timemodified", "title", "userfullname", "userid", "userurl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreSearchGetResultsResponseResultsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if description1 (nullable) is None
        # and model_fields_set contains the field
        if self.description1 is None and "description1" in self.model_fields_set:
            _dict['description1'] = None

        # set to None if description2 (nullable) is None
        # and model_fields_set contains the field
        if self.description2 is None and "description2" in self.model_fields_set:
            _dict['description2'] = None

        # set to None if iconurl (nullable) is None
        # and model_fields_set contains the field
        if self.iconurl is None and "iconurl" in self.model_fields_set:
            _dict['iconurl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreSearchGetResultsResponseResultsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreSearchGetResultsResponseResultsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "areaname": obj.get("areaname") if obj.get("areaname") is not None else '',
            "componentname": obj.get("componentname") if obj.get("componentname") is not None else '',
            "content": obj.get("content") if obj.get("content") is not None else '',
            "contextid": obj.get("contextid") if obj.get("contextid") is not None else 0,
            "contexturl": obj.get("contexturl") if obj.get("contexturl") is not None else '',
            "coursefullname": obj.get("coursefullname") if obj.get("coursefullname") is not None else '',
            "courseurl": obj.get("courseurl") if obj.get("courseurl") is not None else '',
            "description1": obj.get("description1") if obj.get("description1") is not None else '',
            "description2": obj.get("description2") if obj.get("description2") is not None else '',
            "docurl": obj.get("docurl") if obj.get("docurl") is not None else '',
            "filename": obj.get("filename") if obj.get("filename") is not None else '',
            "filenames": obj.get("filenames") if obj.get("filenames") is not None else '',
            "iconurl": obj.get("iconurl") if obj.get("iconurl") is not None else '',
            "itemid": obj.get("itemid") if obj.get("itemid") is not None else 0,
            "multiplefiles": obj.get("multiplefiles") if obj.get("multiplefiles") is not None else 0,
            "textformat": obj.get("textformat") if obj.get("textformat") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "title": obj.get("title") if obj.get("title") is not None else '',
            "userfullname": obj.get("userfullname") if obj.get("userfullname") is not None else '',
            "userid": obj.get("userid") if obj.get("userid") is not None else 0,
            "userurl": obj.get("userurl") if obj.get("userurl") is not None else ''
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner import CoreEnrolGetPotentialUsersResponseInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class GradereportGraderGetUsersInReportResponse(BaseModel):
    """
    GradereportGraderGetUsersInReportResponse
    """ # noqa: E501
    users: List[CoreEnrolGetPotentialUsersResponseInner]
    warnings: Optional[List[AuthEmailGetSignupSettingsResponseWarningsInner]] = Field(default=None, description="list of warnings")
    __properties: ClassVar[List[str]] = ["users", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GradereportGraderGetUsersInReportResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item_users in self.users:
                if _item_users:
                    _items.append(_item_users.to_dict())
            _dict['users'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item_warnings in self.warnings:
                if _item_warnings:
                    _items.append(_item_warnings.to_dict())
            _dict['warnings'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GradereportGraderGetUsersInReportResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "GradereportGraderGetUsersInReportResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "users": [CoreEnrolGetPotentialUsersResponseInner.from_dict(_item) for _item in obj["users"]] if obj.get("users") is not None else None,
            "warnings": [AuthEmailGetSignupSettingsResponseWarningsInner.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreBlogGetEntriesResponseEntriesInner(BaseModel):
    """
    CoreBlogGetEntriesResponseEntriesInner
    """ # noqa: E501
    attachment: Optional[StrictStr] = Field(description="Post atachment.")
    attachmentfiles: Optional[List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner]] = Field(default=None, description="attachmentfiles")
    canedit: Optional[StrictBool] = Field(default=False, description="Whether the user can edit the post.")
    content: Optional[StrictStr] = Field(description="Post content.")
    courseid: StrictInt = Field(description="Course where the post was created.")
    coursemoduleid: StrictInt = Field(description="Course module id where the post was created.")
    created: StrictInt = Field(description="When it was created.")
    format: StrictInt = Field(description="Post content format.")
    groupid: StrictInt = Field(description="Group post was created for.")
    id: Optional[StrictInt] = Field(description="Post/entry id.")
    lastmodified: StrictInt = Field(description="When it was last modified.")
    module: StrictStr = Field(description="Where it was published the post (blog, blog_external...).")
    moduleid: StrictInt = Field(description="Module id where the post was created (not used anymore).")
    publishstate: StrictStr = Field(description="Post publish state.")
    rating: StrictInt = Field(description="Post rating.")
    subject: StrictStr = Field(description="Post subject.")
    summary: Optional[StrictStr] = Field(description="Post summary.")
    summaryfiles: List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner] = Field(description="summaryfiles")
    summaryformat: Optional[StrictInt] = Field(default=0, description="summary format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    tags: Optional[List[CoreBlogGetEntriesResponseEntriesInnerTagsInner]] = Field(default=None, description="Tags.")
    uniquehash: StrictStr = Field(description="Post unique hash.")
    userid: StrictInt = Field(description="Post author.")
    usermodified: Optional[StrictInt] = Field(description="User that updated the post.")
    __properties: ClassVar[List[str]] = ["attachment", "attachmentfiles", "canedit", "content", "courseid", "coursemoduleid", "created", "format", "groupid", "id", "lastmodified", "module", "moduleid", "publishstate", "rating", "subject", "summary", "summaryfiles", "summaryformat", "tags", "uniquehash", "userid", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreBlogGetEntriesResponseEntriesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachmentfiles (list)
        _items = []
        if self.attachmentfiles:
            for _item_attachmentfiles in self.attachmentfiles:
                if _item_attachmentfiles:
                    _items.append(_item_attachmentfiles.to_dict())
            _dict['attachmentfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in summaryfiles (list)
        _items = []
        if self.summaryfiles:
            for _item_summaryfiles in self.summaryfiles:
                if _item_summaryfiles:
                    _items.append(_item_summaryfiles.to_dict())
            _dict['summaryfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if attachment (nullable) is None
        # and model_fields_set contains the field
        if self.attachment is None and "attachment" in self.model_fields_set:
            _dict['attachment'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict['summary'] = None

        # set to None if summaryformat (nullable) is None
        # and model_fields_set contains the field
        if self.summaryformat is None and "summaryformat" in self.model_fields_set:
            _dict['summaryformat'] = None

        # set to None if usermodified (nullable) is None
        # and model_fields_set contains the field
        if self.usermodified is None and "usermodified" in self.model_fields_set:
            _dict['usermodified'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreBlogGetEntriesResponseEntriesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreBlogGetEntriesResponseEntriesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "attachment": obj.get("attachment"),
            "attachmentfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["attachmentfiles"]] if obj.get("attachmentfiles") is not None else None,
            "canedit": obj.get("canedit") if obj.get("canedit") is not None else False,
            "content": obj.get("content"),
            "courseid": obj.get("courseid") if obj.get("courseid") is not None else 0,
            "coursemoduleid": obj.get("coursemoduleid") if obj.get("coursemoduleid") is not None else 0,
            "created": obj.get("created") if obj.get("created") is not None else 0,
            "format": obj.get("format") if obj.get("format") is not None else 0,
            "groupid": obj.get("groupid") if obj.get("groupid") is not None else 0,
            "id": obj.get("id"),
            "lastmodified": obj.get("lastmodified") if obj.get("lastmodified") is not None else 0,
            "module": obj.get("module") if obj.get("module") is not None else '',
            "moduleid": obj.get("moduleid") if obj.get("moduleid") is not None else 0,
            "publishstate": obj.get("publishstate") if obj.get("publishstate") is not None else 'draft',
            "rating": obj.get("rating") if obj.get("rating") is not None else 0,
            "subject": obj.get("subject") if obj.get("subject") is not None else '',
            "summary": obj.get("summary"),
            "summaryfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["summaryfiles"]] if obj.get("summaryfiles") is not None else None,
            "summaryformat": obj.get("summaryformat") if obj.get("summaryformat") is not None else 0,
            "tags": [CoreBlogGetEntriesResponseEntriesInnerTagsInner.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "uniquehash": obj.get("uniquehash") if obj.get("uniquehash") is not None else '',
            "userid": obj.get("userid") if obj.get("userid") is not None else 0,
            "usermodified": obj.get("usermodified")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_reportbuilder_reports_get_response_attributes_inner import CoreReportbuilderReportsGetResponseAttributesInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_button import CoreReportbuilderReportsGetResponseButton
from poodle_async_full.models.core_reportbuilder_reports_get_response_cardview import CoreReportbuilderReportsGetResponseCardview
from poodle_async_full.models.core_reportbuilder_reports_get_response_conditions import CoreReportbuilderReportsGetResponseConditions
from poodle_async_full.models.core_reportbuilder_reports_get_response_filters import CoreReportbuilderReportsGetResponseFilters
from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards import CoreReportbuilderReportsGetResponseSidebarmenucards
from poodle_async_full.models.core_reportbuilder_reports_get_response_sorting import CoreReportbuilderReportsGetResponseSorting
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreReportbuilderReportsGetResponse(BaseModel):
    """
    CoreReportbuilderReportsGetResponse
    """ # noqa: E501
    area: StrictStr = Field(description="area")
    attributes: List[CoreReportbuilderReportsGetResponseAttributesInner] = Field(description="attributes")
    button: Optional[CoreReportbuilderReportsGetResponseButton] = None
    cardview: Optional[CoreReportbuilderReportsGetResponseCardview] = None
    classes: StrictStr = Field(description="classes")
    component: StrictStr = Field(description="component")
    conditiondata: Optional[StrictStr] = Field(description="conditiondata")
    conditions: Optional[CoreReportbuilderReportsGetResponseConditions] = None
    contextid: StrictInt = Field(description="contextid")
    editmode: StrictBool = Field(description="editmode")
    filters: Optional[CoreReportbuilderReportsGetResponseFilters] = None
    filtersapplied: StrictInt = Field(description="filtersapplied")
    filtersform: StrictStr = Field(description="filtersform")
    filterspresent: StrictBool = Field(description="filterspresent")
    id: StrictInt = Field(description="id")
    infocontainer: StrictStr = Field(description="infocontainer")
    itemid: StrictInt = Field(description="itemid")
    javascript: StrictStr = Field(description="javascript")
    name: Optional[StrictStr] = Field(description="name")
    settingsdata: Optional[StrictStr] = Field(description="settingsdata")
    sidebarmenucards: Optional[CoreReportbuilderReportsGetResponseSidebarmenucards] = None
    sorting: Optional[CoreReportbuilderReportsGetResponseSorting] = None
    source: StrictStr = Field(description="source")
    table: StrictStr = Field(description="table")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    type: StrictInt = Field(description="type")
    uniquerows: StrictBool = Field(description="uniquerows")
    usercreated: StrictInt = Field(description="usercreated")
    usermodified: StrictInt = Field(description="usermodified")
    __properties: ClassVar[List[str]] = ["area", "attributes", "button", "cardview", "classes", "component", "conditiondata", "conditions", "contextid", "editmode", "filters", "filtersapplied", "filtersform", "filterspresent", "id", "infocontainer", "itemid", "javascript", "name", "settingsdata", "sidebarmenucards", "sorting", "source", "table", "timecreated", "timemodified", "type", "uniquerows", "usercreated", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreReportbuilderReportsGetResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attributes (list)
        _items = []
        if self.attributes:
            for _item_attributes in self.attributes:
                if _item_attributes:
                    _items.append(_item_attributes.to_dict())
            _dict['attributes'] = _items
        # override the default output from pydantic by calling `to_dict()` of button
        if self.button:
            _dict['button'] = self.button.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cardview
        if self.cardview:
            _dict['cardview'] = self.cardview.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conditions
        if self.conditions:
            _dict['conditions'] = self.conditions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of filters
        if self.filters:
            _dict['filters'] = self.filters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sidebarmenucards
        if self.sidebarmenucards:
            _dict['sidebarmenucards'] = self.sidebarmenucards.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sorting
        if self.sorting:
            _dict['sorting'] = self.sorting.to_dict()
        # set to None if conditiondata (nullable) is None
        # and model_fields_set contains the field
        if self.conditiondata is None and "conditiondata" in self.model_fields_set:
            _dict['conditiondata'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if settingsdata (nullable) is None
        # and model_fields_set contains the field
        if self.settingsdata is None and "settingsdata" in self.model_fields_set:
            _dict['settingsdata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreReportbuilderReportsGetResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreReportbuilderReportsGetResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "area": obj.get("area") if obj.get("area") is not None else '',
            "attributes": [CoreReportbuilderReportsGetResponseAttributesInner.from_dict(_item) for _item in obj["attributes"]] if obj.get("attributes") is not None else None,
            "button": CoreReportbuilderReportsGetResponseButton.from_dict(obj["button"]) if obj.get("button") is not None else None,
            "cardview": CoreReportbuilderReportsGetResponseCardview.from_dict(obj["cardview"]) if obj.get("cardview") is not None else None,
            "classes": obj.get("classes") if obj.get("classes") is not None else '',
            "component": obj.get("component") if obj.get("component") is not None else '',
            "conditiondata": obj.get("conditiondata"),
            "conditions": CoreReportbuilderReportsGetResponseConditions.from_dict(obj["conditions"]) if obj.get("conditions") is not None else None,
            "contextid": obj.get("contextid") if obj.get("contextid") is not None else 0,
            "editmode": obj.get("editmode") if obj.get("editmode") is not None else False,
            "filters": CoreReportbuilderReportsGetResponseFilters.from_dict(obj["filters"]) if obj.get("filters") is not None else None,
            "filtersapplied": obj.get("filtersapplied") if obj.get("filtersapplied") is not None else 0,
            "filtersform": obj.get("filtersform") if obj.get("filtersform") is not None else '',
            "filterspresent": obj.get("filterspresent") if obj.get("filterspresent") is not None else False,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "infocontainer": obj.get("infocontainer") if obj.get("infocontainer") is not None else '',
            "itemid": obj.get("itemid") if obj.get("itemid") is not None else 0,
            "javascript": obj.get("javascript") if obj.get("javascript") is not None else '',
            "name": obj.get("name"),
            "settingsdata": obj.get("settingsdata"),
            "sidebarmenucards": CoreReportbuilderReportsGetResponseSidebarmenucards.from_dict(obj["sidebarmenucards"]) if obj.get("sidebarmenucards") is not None else None,
            "sorting": CoreReportbuilderReportsGetResponseSorting.from_dict(obj["sorting"]) if obj.get("sorting") is not None else None,
            "source": obj.get("source") if obj.get("source") is not None else '',
            "table": obj.get("table") if obj.get("table") is not None else '',
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "type": obj.get("type") if obj.get("type") is not None else 0,
            "uniquerows": obj.get("uniquerows") if obj.get("uniquerows") is not None else False,
            "usercreated": obj.get("usercreated") if obj.get("usercreated") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModLessonGetAttemptsOverviewResponseData(BaseModel):
    """
    Attempts overview data (empty for no attemps).
    """ # noqa: E501
    avescore: Optional[Union[StrictFloat, StrictInt]] = Field(description="Average score.")
    avetime: Optional[StrictInt] = Field(description="Average time (spent in taking the lesson).")
    highscore: Optional[Union[StrictFloat, StrictInt]] = Field(description="High score.")
    hightime: Optional[StrictInt] = Field(description="High time.")
    lessonscored: Optional[StrictBool] = Field(description="True if the lesson was scored.")
    lowscore: Optional[Union[StrictFloat, StrictInt]] = Field(description="Low score.")
    lowtime: Optional[StrictInt] = Field(description="Low time.")
    numofattempts: Optional[StrictInt] = Field(description="Number of attempts.")
    students: Optional[List[ModLessonGetAttemptsOverviewResponseDataStudentsInner]] = Field(default=None, description="Students data, including attempts.")
    __properties: ClassVar[List[str]] = ["avescore", "avetime", "highscore", "hightime", "lessonscored", "lowscore", "lowtime", "numofattempts", "students"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModLessonGetAttemptsOverviewResponseData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in students (list)
        _items = []
        if self.students:
            for _item_students in self.students:
                if _item_students:
                    _items.append(_item_students.to_dict())
            _dict['students'] = _items
        # set to None if avescore (nullable) is None
        # and model_fields_set contains the field
        if self.avescore is None and "avescore" in self.model_fields_set:
            _dict['avescore'] = None

        # set to None if avetime (nullable) is None
        # and model_fields_set contains the field
        if self.avetime is None and "avetime" in self.model_fields_set:
            _dict['avetime'] = None

        # set to None if highscore (nullable) is None
        # and model_fields_set contains the field
        if self.highscore is None and "highscore" in self.model_fields_set:
            _dict['highscore'] = None

        # set to None if hightime (nullable) is None
        # and model_fields_set contains the field
        if self.hightime is None and "hightime" in self.model_fields_set:
            _dict['hightime'] = None

        # set to None if lessonscored (nullable) is None
        # and model_fields_set contains the field
        if self.lessonscored is None and "lessonscored" in self.model_fields_set:
            _dict['lessonscored'] = None

        # set to None if lowscore (nullable) is None
        # and model_fields_set contains the field
        if self.lowscore is None and "lowscore" in self.model_fields_set:
            _dict['lowscore'] = None

        # set to None if lowtime (nullable) is None
        # and model_fields_set contains the field
        if self.lowtime is None and "lowtime" in self.model_fields_set:
            _dict['lowtime'] = None

        # set to None if numofattempts (nullable) is None
        # and model_fields_set contains the field
        if self.numofattempts is None and "numofattempts" in self.model_fields_set:
            _dict['numofattempts'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModLessonGetAttemptsOverviewResponseData from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModLessonGetAttemptsOverviewResponseData" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "avescore": obj.get("avescore"),
            "avetime": obj.get("avetime"),
            "highscore": obj.get("highscore"),
            "hightime": obj.get("hightime"),
            "lessonscored": obj.get("lessonscored"),
            "lowscore": obj.get("lowscore"),
            "lowtime": obj.get("lowtime"),
            "numofattempts": obj.get("numofattempts"),
            "students": [ModLessonGetAttemptsOverviewResponseDataStudentsInner.from_dict(_item) for _item in obj["students"]] if obj.get("students") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class BlockStarredcoursesGetStarredCoursesResponseInner(BaseModel):
    """
    BlockStarredcoursesGetStarredCoursesResponseInner
    """ # noqa: E501
    coursecategory: StrictStr = Field(description="coursecategory")
    courseimage: StrictStr = Field(description="courseimage")
    enddate: StrictInt = Field(description="enddate")
    fullname: StrictStr = Field(description="fullname")
    fullnamedisplay: StrictStr = Field(description="fullnamedisplay")
    hasprogress: StrictBool = Field(description="hasprogress")
    hidden: StrictBool = Field(description="hidden")
    id: StrictInt = Field(description="id")
    idnumber: StrictStr = Field(description="idnumber")
    isfavourite: StrictBool = Field(description="isfavourite")
    pdfexportfont: Optional[StrictStr] = Field(description="pdfexportfont")
    progress: Optional[StrictInt] = Field(default=0, description="progress")
    shortname: StrictStr = Field(description="shortname")
    showactivitydates: Optional[StrictBool] = Field(description="showactivitydates")
    showcompletionconditions: Optional[StrictBool] = Field(description="showcompletionconditions")
    showshortname: StrictBool = Field(description="showshortname")
    startdate: StrictInt = Field(description="startdate")
    summary: Optional[StrictStr] = Field(description="summary")
    summaryformat: Optional[StrictInt] = Field(default=0, description="summary format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    timeaccess: Optional[StrictInt] = Field(default=0, description="timeaccess")
    viewurl: StrictStr = Field(description="viewurl")
    visible: StrictBool = Field(description="visible")
    __properties: ClassVar[List[str]] = ["coursecategory", "courseimage", "enddate", "fullname", "fullnamedisplay", "hasprogress", "hidden", "id", "idnumber", "isfavourite", "pdfexportfont", "progress", "shortname", "showactivitydates", "showcompletionconditions", "showshortname", "startdate", "summary", "summaryformat", "timeaccess", "viewurl", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BlockStarredcoursesGetStarredCoursesResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if pdfexportfont (nullable) is None
        # and model_fields_set contains the field
        if self.pdfexportfont is None and "pdfexportfont" in self.model_fields_set:
            _dict['pdfexportfont'] = None

        # set to None if showactivitydates (nullable) is None
        # and model_fields_set contains the field
        if self.showactivitydates is None and "showactivitydates" in self.model_fields_set:
            _dict['showactivitydates'] = None

        # set to None if showcompletionconditions (nullable) is None
        # and model_fields_set contains the field
        if self.showcompletionconditions is None and "showcompletionconditions" in self.model_fields_set:
            _dict['showcompletionconditions'] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict['summary'] = None

        # set to None if summaryformat (nullable) is None
        # and model_fields_set contains the field
        if self.summaryformat is None and "summaryformat" in self.model_fields_set:
            _dict['summaryformat'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BlockStarredcoursesGetStarredCoursesResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "BlockStarredcoursesGetStarredCoursesResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "coursecategory": obj.get("coursecategory") if obj.get("coursecategory") is not None else '',
            "courseimage": obj.get("courseimage") if obj.get("courseimage") is not None else '',
            "enddate": obj.get("enddate") if obj.get("enddate") is not None else 0,
            "fullname": obj.get("fullname") if obj.get("fullname") is not None else '',
            "fullnamedisplay": obj.get("fullnamedisplay") if obj.get("fullnamedisplay") is not None else '',
            "hasprogress": obj.get("hasprogress") if obj.get("hasprogress") is not None else False,
            "hidden": obj.get("hidden") if obj.get("hidden") is not None else False,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "idnumber": obj.get("idnumber") if obj.get("idnumber") is not None else '',
            "isfavourite": obj.get("isfavourite") if obj.get("isfavourite") is not None else False,
            "pdfexportfont": obj.get("pdfexportfont"),
            "progress": obj.get("progress") if obj.get("progress") is not None else 0,
            "shortname": obj.get("shortname") if obj.get("shortname") is not None else '',
            "showactivitydates": obj.get("showactivitydates"),
            "showcompletionconditions": obj.get("showcompletionconditions"),
            "showshortname": obj.get("showshortname") if obj.get("showshortname") is not None else False,
            "startdate": obj.get("startdate") if obj.get("startdate") is not None else 0,
            "summary": obj.get("summary"),
            "summaryformat": obj.get("summaryformat") if obj.get("summaryformat") is not None else 0,
            "timeaccess": obj.get("timeaccess") if obj.get("timeaccess") is not None else 0,
            "viewurl": obj.get("viewurl") if obj.get("viewurl") is not None else '',
            "visible": obj.get("visible") if obj.get("visible") is not None else False
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCompetencyCreateTemplateParametersTemplate(BaseModel):
    """
    CoreCompetencyCreateTemplateParametersTemplate
    """ # noqa: E501
    contextid: Optional[StrictInt] = Field(default=None, description="The context id")
    contextlevel: Optional[StrictStr] = Field(default=None, description="The context level")
    description: Optional[StrictStr] = Field(default='', description="description")
    descriptionformat: Optional[StrictInt] = Field(default=1, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    duedate: Optional[StrictInt] = Field(default=0, description="duedate")
    instanceid: Optional[StrictInt] = Field(default=None, description="The Instance id")
    shortname: StrictStr = Field(description="shortname")
    timecreated: Optional[StrictInt] = Field(default=0, description="timecreated")
    timemodified: Optional[StrictInt] = Field(default=0, description="timemodified")
    usermodified: Optional[StrictInt] = Field(default=0, description="usermodified")
    visible: Optional[StrictBool] = Field(default=True, description="visible")
    __properties: ClassVar[List[str]] = ["contextid", "contextlevel", "description", "descriptionformat", "duedate", "instanceid", "shortname", "timecreated", "timemodified", "usermodified", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCompetencyCreateTemplateParametersTemplate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if contextid (nullable) is None
        # and model_fields_set contains the field
        if self.contextid is None and "contextid" in self.model_fields_set:
            _dict['contextid'] = None

        # set to None if contextlevel (nullable) is None
        # and model_fields_set contains the field
        if self.contextlevel is None and "contextlevel" in self.model_fields_set:
            _dict['contextlevel'] = None

        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if instanceid (nullable) is None
        # and model_fields_set contains the field
        if self.instanceid is None and "instanceid" in self.model_fields_set:
            _dict['instanceid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCompetencyCreateTemplateParametersTemplate from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCompetencyCreateTemplateParametersTemplate" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "contextid": obj.get("contextid"),
            "contextlevel": obj.get("contextlevel"),
            "description": obj.get("description") if obj.get("description") is not None else '',
            "descriptionformat": obj.get("descriptionformat") if obj.get("descriptionformat") is not None else 1,
            "duedate": obj.get("duedate") if obj.get("duedate") is not None else 0,
            "instanceid": obj.get("instanceid"),
            "shortname": obj.get("shortname") if obj.get("shortname") is not None else '',
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0,
            "visible": obj.get("visible") if obj.get("visible") is not None else True
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_configs_inner import CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents import CoreBlockGetCourseBlocksResponseBlocksInnerContents
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreBlockGetCourseBlocksResponseBlocksInner(BaseModel):
    """
    Block information.
    """ # noqa: E501
    collapsible: Optional[StrictBool] = Field(description="Whether the block is collapsible.")
    configs: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner]] = Field(default=None, description="Block instance and plugin configuration settings.")
    contents: Optional[CoreBlockGetCourseBlocksResponseBlocksInnerContents] = None
    dockable: Optional[StrictBool] = Field(description="Whether the block is dockable.")
    instanceid: Optional[StrictInt] = Field(description="Block instance id.")
    name: Optional[StrictStr] = Field(description="Block name.")
    positionid: Optional[StrictInt] = Field(description="Position id.")
    region: Optional[StrictStr] = Field(description="Block region.")
    visible: Optional[StrictBool] = Field(default=None, description="Whether the block is visible.")
    weight: Optional[StrictInt] = Field(default=None, description="Used to order blocks within a region.")
    __properties: ClassVar[List[str]] = ["collapsible", "configs", "contents", "dockable", "instanceid", "name", "positionid", "region", "visible", "weight"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreBlockGetCourseBlocksResponseBlocksInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in configs (list)
        _items = []
        if self.configs:
            for _item_configs in self.configs:
                if _item_configs:
                    _items.append(_item_configs.to_dict())
            _dict['configs'] = _items
        # override the default output from pydantic by calling `to_dict()` of contents
        if self.contents:
            _dict['contents'] = self.contents.to_dict()
        # set to None if collapsible (nullable) is None
        # and model_fields_set contains the field
        if self.collapsible is None and "collapsible" in self.model_fields_set:
            _dict['collapsible'] = None

        # set to None if dockable (nullable) is None
        # and model_fields_set contains the field
        if self.dockable is None and "dockable" in self.model_fields_set:
            _dict['dockable'] = None

        # set to None if instanceid (nullable) is None
        # and model_fields_set contains the field
        if self.instanceid is None and "instanceid" in self.model_fields_set:
            _dict['instanceid'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if positionid (nullable) is None
        # and model_fields_set contains the field
        if self.positionid is None and "positionid" in self.model_fields_set:
            _dict['positionid'] = None

        # set to None if region (nullable) is None
        # and model_fields_set contains the field
        if self.region is None and "region" in self.model_fields_set:
            _dict['region'] = None

        # set to None if visible (nullable) is None
        # and model_fields_set contains the field
        if self.visible is None and "visible" in self.model_fields_set:
            _dict['visible'] = None

        # set to None if weight (nullable) is None
        # and model_fields_set contains the field
        if self.weight is None and "weight" in self.model_fields_set:
            _dict['weight'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreBlockGetCourseBlocksResponseBlocksInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreBlockGetCourseBlocksResponseBlocksInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "collapsible": obj.get("collapsible"),
            "configs": [CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner.from_dict(_item) for _item in obj["configs"]] if obj.get("configs") is not None else None,
            "contents": CoreBlockGetCourseBlocksResponseBlocksInnerContents.from_dict(obj["contents"]) if obj.get("contents") is not None else None,
            "dockable": obj.get("dockable"),
            "instanceid": obj.get("instanceid"),
            "name": obj.get("name"),
            "positionid": obj.get("positionid"),
            "region": obj.get("region"),
            "visible": obj.get("visible"),
            "weight": obj.get("weight")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner
from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer
from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields import CoreReportbuilderListReportsResponseReportsInnerCustomfields
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreReportbuilderListReportsResponseReportsInner(BaseModel):
    """
    CoreReportbuilderListReportsResponseReportsInner
    """ # noqa: E501
    area: StrictStr = Field(description="area")
    component: StrictStr = Field(description="component")
    conditiondata: Optional[StrictStr] = Field(description="conditiondata")
    contextid: StrictInt = Field(description="contextid")
    customfields: CoreReportbuilderListReportsResponseReportsInnerCustomfields
    id: StrictInt = Field(description="id")
    itemid: StrictInt = Field(description="itemid")
    modifiedby: CoreCompetencyCreatePlanResponseReviewer
    name: Optional[StrictStr] = Field(description="name")
    settingsdata: Optional[StrictStr] = Field(description="settingsdata")
    source: StrictStr = Field(description="source")
    sourcename: Optional[StrictStr] = Field(description="sourcename")
    tags: List[CoreBlogGetEntriesResponseEntriesInnerTagsInner] = Field(description="tags")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    type: StrictInt = Field(description="type")
    uniquerows: StrictBool = Field(description="uniquerows")
    usercreated: StrictInt = Field(description="usercreated")
    usermodified: StrictInt = Field(description="usermodified")
    __properties: ClassVar[List[str]] = ["area", "component", "conditiondata", "contextid", "customfields", "id", "itemid", "modifiedby", "name", "settingsdata", "source", "sourcename", "tags", "timecreated", "timemodified", "type", "uniquerows", "usercreated", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreReportbuilderListReportsResponseReportsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of customfields
        if self.customfields:
            _dict['customfields'] = self.customfields.to_dict()
        # override the default output from pydantic by calling `to_dict()` of modifiedby
        if self.modifiedby:
            _dict['modifiedby'] = self.modifiedby.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in tags (list)
        _items = []
        if self.tags:
            for _item_tags in self.tags:
                if _item_tags:
                    _items.append(_item_tags.to_dict())
            _dict['tags'] = _items
        # set to None if conditiondata (nullable) is None
        # and model_fields_set contains the field
        if self.conditiondata is None and "conditiondata" in self.model_fields_set:
            _dict['conditiondata'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if settingsdata (nullable) is None
        # and model_fields_set contains the field
        if self.settingsdata is None and "settingsdata" in self.model_fields_set:
            _dict['settingsdata'] = None

        # set to None if sourcename (nullable) is None
        # and model_fields_set contains the field
        if self.sourcename is None and "sourcename" in self.model_fields_set:
            _dict['sourcename'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreReportbuilderListReportsResponseReportsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreReportbuilderListReportsResponseReportsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "area": obj.get("area") if obj.get("area") is not None else '',
            "component": obj.get("component") if obj.get("component") is not None else '',
            "conditiondata": obj.get("conditiondata"),
            "contextid": obj.get("contextid") if obj.get("contextid") is not None else 0,
            "customfields": CoreReportbuilderListReportsResponseReportsInnerCustomfields.from_dict(obj["customfields"]) if obj.get("customfields") is not None else None,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "itemid": obj.get("itemid") if obj.get("itemid") is not None else 0,
            "modifiedby": CoreCompetencyCreatePlanResponseReviewer.from_dict(obj["modifiedby"]) if obj.get("modifiedby") is not None else None,
            "name": obj.get("name"),
            "settingsdata": obj.get("settingsdata"),
            "source": obj.get("source") if obj.get("source") is not None else '',
            "sourcename": obj.get("sourcename"),
            "tags": [CoreBlogGetEntriesResponseEntriesInnerTagsInner.from_dict(_item) for _item in obj["tags"]] if obj.get("tags") is not None else None,
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "type": obj.get("type") if obj.get("type") is not None else 0,
            "uniquerows": obj.get("uniquerows") if obj.get("uniquerows") is not None else False,
            "usercreated": obj.get("usercreated") if obj.get("usercreated") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModLessonGetPageDataResponseAnswersInner(BaseModel):
    """
    The page answers
    """ # noqa: E501
    answer: Optional[StrictStr] = Field(default=None, description="Possible answer text")
    answerfiles: List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner] = Field(description="List of files.")
    answerformat: Optional[StrictInt] = Field(default=None, description="answer format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    flags: Optional[StrictInt] = Field(default=None, description="Used to store options for the answer")
    grade: Optional[StrictInt] = Field(default=None, description="The grade this answer is worth")
    id: Optional[StrictInt] = Field(description="The ID of this answer in the database")
    jumpto: Optional[StrictInt] = Field(default=None, description="Identifies where the user goes upon completing a page with this answer")
    response: Optional[StrictStr] = Field(default=None, description="Response text for the answer")
    responsefiles: List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner] = Field(description="List of files.")
    responseformat: Optional[StrictInt] = Field(default=None, description="response format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    score: Optional[StrictInt] = Field(default=None, description="The score this answer will give")
    timecreated: Optional[StrictInt] = Field(default=None, description="A timestamp of when the answer was created")
    timemodified: Optional[StrictInt] = Field(default=None, description="A timestamp of when the answer was modified")
    __properties: ClassVar[List[str]] = ["answer", "answerfiles", "answerformat", "flags", "grade", "id", "jumpto", "response", "responsefiles", "responseformat", "score", "timecreated", "timemodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModLessonGetPageDataResponseAnswersInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in answerfiles (list)
        _items = []
        if self.answerfiles:
            for _item_answerfiles in self.answerfiles:
                if _item_answerfiles:
                    _items.append(_item_answerfiles.to_dict())
            _dict['answerfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in responsefiles (list)
        _items = []
        if self.responsefiles:
            for _item_responsefiles in self.responsefiles:
                if _item_responsefiles:
                    _items.append(_item_responsefiles.to_dict())
            _dict['responsefiles'] = _items
        # set to None if answer (nullable) is None
        # and model_fields_set contains the field
        if self.answer is None and "answer" in self.model_fields_set:
            _dict['answer'] = None

        # set to None if answerformat (nullable) is None
        # and model_fields_set contains the field
        if self.answerformat is None and "answerformat" in self.model_fields_set:
            _dict['answerformat'] = None

        # set to None if flags (nullable) is None
        # and model_fields_set contains the field
        if self.flags is None and "flags" in self.model_fields_set:
            _dict['flags'] = None

        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if jumpto (nullable) is None
        # and model_fields_set contains the field
        if self.jumpto is None and "jumpto" in self.model_fields_set:
            _dict['jumpto'] = None

        # set to None if response (nullable) is None
        # and model_fields_set contains the field
        if self.response is None and "response" in self.model_fields_set:
            _dict['response'] = None

        # set to None if responseformat (nullable) is None
        # and model_fields_set contains the field
        if self.responseformat is None and "responseformat" in self.model_fields_set:
            _dict['responseformat'] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict['score'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModLessonGetPageDataResponseAnswersInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModLessonGetPageDataResponseAnswersInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "answer": obj.get("answer"),
            "answerfiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["answerfiles"]] if obj.get("answerfiles") is not None else None,
            "answerformat": obj.get("answerformat"),
            "flags": obj.get("flags"),
            "grade": obj.get("grade"),
            "id": obj.get("id"),
            "jumpto": obj.get("jumpto"),
            "response": obj.get("response"),
            "responsefiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["responsefiles"]] if obj.get("responsefiles") is not None else None,
            "responseformat": obj.get("responseformat"),
            "score": obj.get("score"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModScormGetScormAccessInformationResponse(BaseModel):
    """
    ModScormGetScormAccessInformationResponse
    """ # noqa: E501
    canaddinstance: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/scorm:addinstance allowed.")
    candeleteownresponses: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/scorm:deleteownresponses allowed.")
    candeleteresponses: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/scorm:deleteresponses allowed.")
    cansavetrack: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/scorm:savetrack allowed.")
    canskipview: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/scorm:skipview allowed.")
    canviewreport: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/scorm:viewreport allowed.")
    canviewscores: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/scorm:viewscores allowed.")
    warnings: Optional[List[AuthEmailGetSignupSettingsResponseWarningsInner]] = Field(default=None, description="list of warnings")
    __properties: ClassVar[List[str]] = ["canaddinstance", "candeleteownresponses", "candeleteresponses", "cansavetrack", "canskipview", "canviewreport", "canviewscores", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModScormGetScormAccessInformationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item_warnings in self.warnings:
                if _item_warnings:
                    _items.append(_item_warnings.to_dict())
            _dict['warnings'] = _items
        # set to None if canaddinstance (nullable) is None
        # and model_fields_set contains the field
        if self.canaddinstance is None and "canaddinstance" in self.model_fields_set:
            _dict['canaddinstance'] = None

        # set to None if candeleteownresponses (nullable) is None
        # and model_fields_set contains the field
        if self.candeleteownresponses is None and "candeleteownresponses" in self.model_fields_set:
            _dict['candeleteownresponses'] = None

        # set to None if candeleteresponses (nullable) is None
        # and model_fields_set contains the field
        if self.candeleteresponses is None and "candeleteresponses" in self.model_fields_set:
            _dict['candeleteresponses'] = None

        # set to None if cansavetrack (nullable) is None
        # and model_fields_set contains the field
        if self.cansavetrack is None and "cansavetrack" in self.model_fields_set:
            _dict['cansavetrack'] = None

        # set to None if canskipview (nullable) is None
        # and model_fields_set contains the field
        if self.canskipview is None and "canskipview" in self.model_fields_set:
            _dict['canskipview'] = None

        # set to None if canviewreport (nullable) is None
        # and model_fields_set contains the field
        if self.canviewreport is None and "canviewreport" in self.model_fields_set:
            _dict['canviewreport'] = None

        # set to None if canviewscores (nullable) is None
        # and model_fields_set contains the field
        if self.canviewscores is None and "canviewscores" in self.model_fields_set:
            _dict['canviewscores'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModScormGetScormAccessInformationResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModScormGetScormAccessInformationResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "canaddinstance": obj.get("canaddinstance"),
            "candeleteownresponses": obj.get("candeleteownresponses"),
            "candeleteresponses": obj.get("candeleteresponses"),
            "cansavetrack": obj.get("cansavetrack"),
            "canskipview": obj.get("canskipview"),
            "canviewreport": obj.get("canviewreport"),
            "canviewscores": obj.get("canviewscores"),
            "warnings": [AuthEmailGetSignupSettingsResponseWarningsInner.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_enrolledcourses_inner import CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_roles_inner import CoreEnrolGetEnrolledUsersResponseInnerRolesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_groups_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner_customfields_inner import CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner_preferences_inner import CoreEnrolGetPotentialUsersResponseInnerPreferencesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModAssignListParticipantsResponseInner(BaseModel):
    """
    ModAssignListParticipantsResponseInner
    """ # noqa: E501
    address: Optional[StrictStr] = Field(default=None, description="Postal address")
    city: Optional[StrictStr] = Field(default=None, description="Home city of the user")
    country: Optional[StrictStr] = Field(default=None, description="Home country code of the user, such as AU or CZ")
    customfields: Optional[List[CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner]] = Field(default=None, description="User custom fields (also known as user profile fields)")
    department: Optional[StrictStr] = Field(default=None, description="department")
    description: Optional[StrictStr] = Field(default=None, description="User profile description")
    descriptionformat: Optional[StrictInt] = Field(default=None, description="int format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    email: Optional[StrictStr] = Field(default=None, description="Email address")
    enrolledcourses: Optional[List[CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner]] = Field(default=None, description="Courses where the user is enrolled - limited by which courses the user is able to see")
    firstaccess: Optional[StrictInt] = Field(default=None, description="first access to the site (0 if never)")
    firstname: Optional[StrictStr] = Field(default=None, description="The first name(s) of the user")
    fullname: Optional[StrictStr] = Field(description="The fullname of the user")
    grantedextension: Optional[StrictBool] = Field(description="have they been granted an extension")
    groupid: Optional[StrictInt] = Field(default=None, description="for group assignments this is the group id")
    groupname: Optional[StrictStr] = Field(default=None, description="for group assignments this is the group name")
    groups: Optional[List[CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner]] = Field(default=None, description="user groups")
    id: Optional[StrictInt] = Field(description="ID of the user")
    idnumber: Optional[StrictStr] = Field(default=None, description="The idnumber of the user")
    institution: Optional[StrictStr] = Field(default=None, description="institution")
    interests: Optional[StrictStr] = Field(default=None, description="user interests (separated by commas)")
    lastaccess: Optional[StrictInt] = Field(default=None, description="last access to the site (0 if never)")
    lastname: Optional[StrictStr] = Field(default=None, description="The family name of the user")
    phone1: Optional[StrictStr] = Field(default=None, description="Phone 1")
    phone2: Optional[StrictStr] = Field(default=None, description="Phone 2")
    preferences: Optional[List[CoreEnrolGetPotentialUsersResponseInnerPreferencesInner]] = Field(default=None, description="Users preferences")
    profileimageurl: Optional[StrictStr] = Field(default=None, description="User image profile URL - big version")
    profileimageurlsmall: Optional[StrictStr] = Field(default=None, description="User image profile URL - small version")
    recordid: Optional[StrictInt] = Field(description="record id")
    requiregrading: Optional[StrictBool] = Field(description="is their submission waiting for grading")
    roles: Optional[List[CoreEnrolGetEnrolledUsersResponseInnerRolesInner]] = Field(default=None, description="user roles")
    submissionstatus: Optional[StrictStr] = Field(default=None, description="The submission status (new, draft, reopened or submitted).                 Empty when not submitted.")
    submitted: Optional[StrictBool] = Field(description="have they submitted their assignment")
    suspended: Optional[StrictBool] = Field(default=None, description="Suspend user account, either false to enable user login or true to disable it")
    trackforums: Optional[StrictInt] = Field(default=None, description="Whether the user is tracking forums.")
    username: Optional[StrictStr] = Field(default=None, description="The username")
    __properties: ClassVar[List[str]] = ["address", "city", "country", "customfields", "department", "description", "descriptionformat", "email", "enrolledcourses", "firstaccess", "firstname", "fullname", "grantedextension", "groupid", "groupname", "groups", "id", "idnumber", "institution", "interests", "lastaccess", "lastname", "phone1", "phone2", "preferences", "profileimageurl", "profileimageurlsmall", "recordid", "requiregrading", "roles", "submissionstatus", "submitted", "suspended", "trackforums", "username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModAssignListParticipantsResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in customfields (list)
        _items = []
        if self.customfields:
            for _item_customfields in self.customfields:
                if _item_customfields:
                    _items.append(_item_customfields.to_dict())
            _dict['customfields'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in enrolledcourses (list)
        _items = []
        if self.enrolledcourses:
            for _item_enrolledcourses in self.enrolledcourses:
                if _item_enrolledcourses:
                    _items.append(_item_enrolledcourses.to_dict())
            _dict['enrolledcourses'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in groups (list)
        _items = []
        if self.groups:
            for _item_groups in self.groups:
                if _item_groups:
                    _items.append(_item_groups.to_dict())
            _dict['groups'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in preferences (list)
        _items = []
        if self.preferences:
            for _item_preferences in self.preferences:
                if _item_preferences:
                    _items.append(_item_preferences.to_dict())
            _dict['preferences'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in roles (list)
        _items = []
        if self.roles:
            for _item_roles in self.roles:
                if _item_roles:
                    _items.append(_item_roles.to_dict())
            _dict['roles'] = _items
        # set to None if address (nullable) is None
        # and model_fields_set contains the field
        if self.address is None and "address" in self.model_fields_set:
            _dict['address'] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if department (nullable) is None
        # and model_fields_set contains the field
        if self.department is None and "department" in self.model_fields_set:
            _dict['department'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if firstaccess (nullable) is None
        # and model_fields_set contains the field
        if self.firstaccess is None and "firstaccess" in self.model_fields_set:
            _dict['firstaccess'] = None

        # set to None if firstname (nullable) is None
        # and model_fields_set contains the field
        if self.firstname is None and "firstname" in self.model_fields_set:
            _dict['firstname'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if grantedextension (nullable) is None
        # and model_fields_set contains the field
        if self.grantedextension is None and "grantedextension" in self.model_fields_set:
            _dict['grantedextension'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if groupname (nullable) is None
        # and model_fields_set contains the field
        if self.groupname is None and "groupname" in self.model_fields_set:
            _dict['groupname'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if idnumber (nullable) is None
        # and model_fields_set contains the field
        if self.idnumber is None and "idnumber" in self.model_fields_set:
            _dict['idnumber'] = None

        # set to None if institution (nullable) is None
        # and model_fields_set contains the field
        if self.institution is None and "institution" in self.model_fields_set:
            _dict['institution'] = None

        # set to None if interests (nullable) is None
        # and model_fields_set contains the field
        if self.interests is None and "interests" in self.model_fields_set:
            _dict['interests'] = None

        # set to None if lastaccess (nullable) is None
        # and model_fields_set contains the field
        if self.lastaccess is None and "lastaccess" in self.model_fields_set:
            _dict['lastaccess'] = None

        # set to None if lastname (nullable) is None
        # and model_fields_set contains the field
        if self.lastname is None and "lastname" in self.model_fields_set:
            _dict['lastname'] = None

        # set to None if phone1 (nullable) is None
        # and model_fields_set contains the field
        if self.phone1 is None and "phone1" in self.model_fields_set:
            _dict['phone1'] = None

        # set to None if phone2 (nullable) is None
        # and model_fields_set contains the field
        if self.phone2 is None and "phone2" in self.model_fields_set:
            _dict['phone2'] = None

        # set to None if profileimageurl (nullable) is None
        # and model_fields_set contains the field
        if self.profileimageurl is None and "profileimageurl" in self.model_fields_set:
            _dict['profileimageurl'] = None

        # set to None if profileimageurlsmall (nullable) is None
        # and model_fields_set contains the field
        if self.profileimageurlsmall is None and "profileimageurlsmall" in self.model_fields_set:
            _dict['profileimageurlsmall'] = None

        # set to None if recordid (nullable) is None
        # and model_fields_set contains the field
        if self.recordid is None and "recordid" in self.model_fields_set:
            _dict['recordid'] = None

        # set to None if requiregrading (nullable) is None
        # and model_fields_set contains the field
        if self.requiregrading is None and "requiregrading" in self.model_fields_set:
            _dict['requiregrading'] = None

        # set to None if submissionstatus (nullable) is None
        # and model_fields_set contains the field
        if self.submissionstatus is None and "submissionstatus" in self.model_fields_set:
            _dict['submissionstatus'] = None

        # set to None if submitted (nullable) is None
        # and model_fields_set contains the field
        if self.submitted is None and "submitted" in self.model_fields_set:
            _dict['submitted'] = None

        # set to None if suspended (nullable) is None
        # and model_fields_set contains the field
        if self.suspended is None and "suspended" in self.model_fields_set:
            _dict['suspended'] = None

        # set to None if trackforums (nullable) is None
        # and model_fields_set contains the field
        if self.trackforums is None and "trackforums" in self.model_fields_set:
            _dict['trackforums'] = None

        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModAssignListParticipantsResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModAssignListParticipantsResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "address": obj.get("address"),
            "city": obj.get("city"),
            "country": obj.get("country"),
            "customfields": [CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner.from_dict(_item) for _item in obj["customfields"]] if obj.get("customfields") is not None else None,
            "department": obj.get("department"),
            "description": obj.get("description"),
            "descriptionformat": obj.get("descriptionformat"),
            "email": obj.get("email"),
            "enrolledcourses": [CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner.from_dict(_item) for _item in obj["enrolledcourses"]] if obj.get("enrolledcourses") is not None else None,
            "firstaccess": obj.get("firstaccess"),
            "firstname": obj.get("firstname"),
            "fullname": obj.get("fullname"),
            "grantedextension": obj.get("grantedextension"),
            "groupid": obj.get("groupid"),
            "groupname": obj.get("groupname"),
            "groups": [CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner.from_dict(_item) for _item in obj["groups"]] if obj.get("groups") is not None else None,
            "id": obj.get("id"),
            "idnumber": obj.get("idnumber"),
            "institution": obj.get("institution"),
            "interests": obj.get("interests"),
            "lastaccess": obj.get("lastaccess"),
            "lastname": obj.get("lastname"),
            "phone1": obj.get("phone1"),
            "phone2": obj.get("phone2"),
            "preferences": [CoreEnrolGetPotentialUsersResponseInnerPreferencesInner.from_dict(_item) for _item in obj["preferences"]] if obj.get("preferences") is not None else None,
            "profileimageurl": obj.get("profileimageurl"),
            "profileimageurlsmall": obj.get("profileimageurlsmall"),
            "recordid": obj.get("recordid"),
            "requiregrading": obj.get("requiregrading"),
            "roles": [CoreEnrolGetEnrolledUsersResponseInnerRolesInner.from_dict(_item) for _item in obj["roles"]] if obj.get("roles") is not None else None,
            "submissionstatus": obj.get("submissionstatus"),
            "submitted": obj.get("submitted"),
            "suspended": obj.get("suspended"),
            "trackforums": obj.get("trackforums"),
            "username": obj.get("username")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_message_get_contact_requests_response_inner_contactrequests_inner import CoreMessageGetContactRequestsResponseInnerContactrequestsInner
from poodle_async_full.models.core_message_get_contact_requests_response_inner_conversations_inner import CoreMessageGetContactRequestsResponseInnerConversationsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreMessageGetContactRequestsResponseInner(BaseModel):
    """
    CoreMessageGetContactRequestsResponseInner
    """ # noqa: E501
    cancreatecontact: Optional[StrictBool] = Field(description="Is the user permitted to add a contact")
    canmessage: Optional[StrictBool] = Field(description="If the user can be messaged")
    canmessageevenifblocked: Optional[StrictBool] = Field(description="If the user can still message even if they get blocked")
    contactrequests: Optional[List[CoreMessageGetContactRequestsResponseInnerContactrequestsInner]] = Field(default=None, description="The contact requests")
    conversations: Optional[List[CoreMessageGetContactRequestsResponseInnerConversationsInner]] = Field(default=None, description="Conversations between users")
    fullname: Optional[StrictStr] = Field(description="The user's name")
    id: Optional[StrictInt] = Field(description="The user id")
    isblocked: Optional[StrictBool] = Field(description="If the user has been blocked")
    iscontact: Optional[StrictBool] = Field(description="Is the user a contact?")
    isdeleted: Optional[StrictBool] = Field(description="Is the user deleted?")
    isonline: Optional[StrictBool] = Field(description="The user's online status")
    profileimageurl: Optional[StrictStr] = Field(description="User picture URL")
    profileimageurlsmall: Optional[StrictStr] = Field(description="Small user picture URL")
    profileurl: Optional[StrictStr] = Field(description="The link to the user's profile page")
    requirescontact: Optional[StrictBool] = Field(description="If the user requires to be contacts")
    showonlinestatus: Optional[StrictBool] = Field(description="Show the user's online status?")
    __properties: ClassVar[List[str]] = ["cancreatecontact", "canmessage", "canmessageevenifblocked", "contactrequests", "conversations", "fullname", "id", "isblocked", "iscontact", "isdeleted", "isonline", "profileimageurl", "profileimageurlsmall", "profileurl", "requirescontact", "showonlinestatus"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreMessageGetContactRequestsResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in contactrequests (list)
        _items = []
        if self.contactrequests:
            for _item_contactrequests in self.contactrequests:
                if _item_contactrequests:
                    _items.append(_item_contactrequests.to_dict())
            _dict['contactrequests'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in conversations (list)
        _items = []
        if self.conversations:
            for _item_conversations in self.conversations:
                if _item_conversations:
                    _items.append(_item_conversations.to_dict())
            _dict['conversations'] = _items
        # set to None if cancreatecontact (nullable) is None
        # and model_fields_set contains the field
        if self.cancreatecontact is None and "cancreatecontact" in self.model_fields_set:
            _dict['cancreatecontact'] = None

        # set to None if canmessage (nullable) is None
        # and model_fields_set contains the field
        if self.canmessage is None and "canmessage" in self.model_fields_set:
            _dict['canmessage'] = None

        # set to None if canmessageevenifblocked (nullable) is None
        # and model_fields_set contains the field
        if self.canmessageevenifblocked is None and "canmessageevenifblocked" in self.model_fields_set:
            _dict['canmessageevenifblocked'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if isblocked (nullable) is None
        # and model_fields_set contains the field
        if self.isblocked is None and "isblocked" in self.model_fields_set:
            _dict['isblocked'] = None

        # set to None if iscontact (nullable) is None
        # and model_fields_set contains the field
        if self.iscontact is None and "iscontact" in self.model_fields_set:
            _dict['iscontact'] = None

        # set to None if isdeleted (nullable) is None
        # and model_fields_set contains the field
        if self.isdeleted is None and "isdeleted" in self.model_fields_set:
            _dict['isdeleted'] = None

        # set to None if isonline (nullable) is None
        # and model_fields_set contains the field
        if self.isonline is None and "isonline" in self.model_fields_set:
            _dict['isonline'] = None

        # set to None if profileimageurl (nullable) is None
        # and model_fields_set contains the field
        if self.profileimageurl is None and "profileimageurl" in self.model_fields_set:
            _dict['profileimageurl'] = None

        # set to None if profileimageurlsmall (nullable) is None
        # and model_fields_set contains the field
        if self.profileimageurlsmall is None and "profileimageurlsmall" in self.model_fields_set:
            _dict['profileimageurlsmall'] = None

        # set to None if profileurl (nullable) is None
        # and model_fields_set contains the field
        if self.profileurl is None and "profileurl" in self.model_fields_set:
            _dict['profileurl'] = None

        # set to None if requirescontact (nullable) is None
        # and model_fields_set contains the field
        if self.requirescontact is None and "requirescontact" in self.model_fields_set:
            _dict['requirescontact'] = None

        # set to None if showonlinestatus (nullable) is None
        # and model_fields_set contains the field
        if self.showonlinestatus is None and "showonlinestatus" in self.model_fields_set:
            _dict['showonlinestatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreMessageGetContactRequestsResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreMessageGetContactRequestsResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "cancreatecontact": obj.get("cancreatecontact"),
            "canmessage": obj.get("canmessage"),
            "canmessageevenifblocked": obj.get("canmessageevenifblocked"),
            "contactrequests": [CoreMessageGetContactRequestsResponseInnerContactrequestsInner.from_dict(_item) for _item in obj["contactrequests"]] if obj.get("contactrequests") is not None else None,
            "conversations": [CoreMessageGetContactRequestsResponseInnerConversationsInner.from_dict(_item) for _item in obj["conversations"]] if obj.get("conversations") is not None else None,
            "fullname": obj.get("fullname"),
            "id": obj.get("id"),
            "isblocked": obj.get("isblocked"),
            "iscontact": obj.get("iscontact"),
            "isdeleted": obj.get("isdeleted"),
            "isonline": obj.get("isonline"),
            "profileimageurl": obj.get("profileimageurl"),
            "profileimageurlsmall": obj.get("profileimageurlsmall"),
            "profileurl": obj.get("profileurl"),
            "requirescontact": obj.get("requirescontact"),
            "showonlinestatus": obj.get("showonlinestatus")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


